@@ -7,7 +7,7 @@ use Rose::HTML::Object::Errors qw(:time);
 use Rose::HTML::Form::Field::Text;
 our @ISA = qw(Rose::HTML::Form::Field::Text);
 
-our $VERSION = '0.01';
+our $VERSION = '0.541';
 
 use Rose::Object::MakeMethods::Generic
 (
@@ -50,6 +50,11 @@ sub validate
   return 1;
 }
 
+if(__PACKAGE__->localizer->auto_load_messages)
+{
+  __PACKAGE__->localizer->load_all_messages;
+}
+
 1;
 
 __DATA__
@@ -58,6 +63,14 @@ __DATA__
 
 TIME_INVALID_HOUR = "Invalid hour."
 
+[% LOCALE de %]
+
+TIME_INVALID_HOUR = "Ungültige Stunde."
+
+[% LOCALE fr %]
+
+TIME_INVALID_HOUR = "Heure invalide."
+
 __END__
 
 =head1 NAME
